var a = 1;
b = 2;

let c = 1,
    d = 2;

var e = 100500,
    + 1;

var f = bar('/protocols/')
baz();

var h = 100500
1;

const i = 1,
      j = 2;

var k = 1,
    l = [
      1, 2,
      3, 4
    ],
    m = 5;

var n = function() {
  return 7;
},
    o = 8;

foo(bar, function() {
  return 2;
});

switch (b) {
case "a":
  2;
default:
  3;
}

var p = {
  case: 'zzzz',
  default: 'donkey',
  tee: 'ornery'
};

var evens = [e for each (e in range(0, 21))
               if (ed % 2 == 0)];

!b
  !=b
  !==b

a++
b +=
  c
